@@ -28,6 +28,15 @@
 #' dbAppendTableArrow(con, "iris", iris[1:5, ])
 #' dbReadTable(con, "iris")
 #' dbDisconnect(con)
-setGeneric("dbAppendTableArrow",
-  def = function(conn, name, value, ...) standardGeneric("dbAppendTableArrow")
-)
+setGeneric("dbAppendTableArrow", def = function(conn, name, value, ...) {
+  otel_local_active_span(
+    "INSERT INTO",
+    conn,
+    label = .dbi_get_collection_name(name, conn),
+    attributes = list(
+      db.collection.name = .dbi_get_collection_name(name, conn),
+      db.operation.name = "INSERT INTO"
+    )
+  )
+  standardGeneric("dbAppendTableArrow")
+})
