@@ -12,8 +12,9 @@
 #' @family DBIDriver generics
 #' @family DBIConnection generics
 #' @family DBIResult generics
+#' @family DBIResultArrow generics
 #' @export
-#' @examples
+#' @examplesIf requireNamespace("RSQLite", quietly = TRUE)
 #' dbIsValid(RSQLite::SQLite())
 #'
 #' con <- dbConnect(RSQLite::SQLite(), ":memory:")
@@ -27,7 +28,8 @@
 #'
 #' dbDisconnect(con)
 #' dbIsValid(con)
-setGeneric("dbIsValid",
+setGeneric(
+  "dbIsValid",
   def = function(dbObj, ...) standardGeneric("dbIsValid"),
   valueClass = "logical"
 )
