@@ -9,7 +9,8 @@ dbWithTransaction_DBIConnection <- function(conn, code) {
         paste(
           "Failed to rollback transaction.",
           "Tried to roll back because an error",
-          "occurred:", conditionMessage(e)
+          "occurred:",
+          conditionMessage(e)
         ),
         call. = FALSE
       )
@@ -34,13 +35,18 @@ dbWithTransaction_DBIConnection <- function(conn, code) {
       res
     },
     dbi_abort = rollback_because,
-    error = rollback_because
+    error = rollback_because,
+    interrupt = rollback_because
   )
 }
 
 #' @rdname hidden_aliases
 #' @export
-setMethod("dbWithTransaction", signature("DBIConnection"), dbWithTransaction_DBIConnection)
+setMethod(
+  "dbWithTransaction",
+  signature("DBIConnection"),
+  dbWithTransaction_DBIConnection
+)
 
 #' @export
 #' @rdname dbWithTransaction
