@@ -24,6 +24,9 @@
 #'
 #' sqlAppendTable(ANSI(), "mtcars", head(mtcars))
 #' sqlAppendTable(ANSI(), "mtcars", head(mtcars), row.names = FALSE)
-setGeneric("sqlAppendTable",
-  def = function(con, table, values, row.names = NA, ...) standardGeneric("sqlAppendTable")
+setGeneric(
+  "sqlAppendTable",
+  def = function(con, table, values, row.names = NA, ...) {
+    standardGeneric("sqlAppendTable")
+  }
 )
